/**
 * @file align_func_params.h
 *
 * @author  Guy Maurel
 * split from align.cpp
 * @author  Ben Gardner
 * @license GPL v2+
 */

#ifndef ALIGN_FUNC_PARAMS_H_INCLUDED
#define ALIGN_FUNC_PARAMS_H_INCLUDED

#include "chunk.h"

void align_func_params();

Chunk *align_func_param(Chunk *start);

#endif /* ALIGN_FUNC_PARAMS_H_INCLUDED */
